==> pointpos_api-0.0.1.tar.gz: docs/PurchaseOrderApi.md <==
# swagger.api.PurchaseOrderApi

## Load the API package
```dart
import 'package:swagger/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createPurchaseorder**](PurchaseOrderApi.md#createPurchaseorder) | **POST** /purchase-order | Create Purchaseorder
[**deletePurchaseorderByID**](PurchaseOrderApi.md#deletePurchaseorderByID) | **DELETE** /purchase-order/{outletId} | Delete Purchaseorder By ID
[**findPurchaseorder**](PurchaseOrderApi.md#findPurchaseorder) | **GET** /purchase-order | Get Purchaseorder List
[**getPurchaseorderByID**](PurchaseOrderApi.md#getPurchaseorderByID) | **GET** /purchase-order/{outletId} | Get Purchaseorder By ID
[**updatePurchaseorderByID**](PurchaseOrderApi.md#updatePurchaseorderByID) | **PUT** /purchase-order/{outletId} | Update Purchaseorder By ID


# **createPurchaseorder**
> PurchaseOrder createPurchaseorder(authorization, xAPIKey, body)

Create Purchaseorder

Create Purchaseorder

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new PurchaseOrder(); // PurchaseOrder | 

try { 
    var result = api_instance.createPurchaseorder(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->createPurchaseorder: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**PurchaseOrder**](PurchaseOrder.md)|  | 

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deletePurchaseorderByID**
> deletePurchaseorderByID(authorization, xAPIKey, outletId)

Delete Purchaseorder By ID

Delete Purchaseorder By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var outletId = outletId_example; // String | 

try { 
    api_instance.deletePurchaseorderByID(authorization, xAPIKey, outletId);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->deletePurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **outletId** | **String**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findPurchaseorder**
> List<PurchaseOrder> findPurchaseorder(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Purchaseorder List

Get Purchaseorder  List

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"outletId\"   - \"supplierId\"   - \"note\"   - \"ingredients\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findPurchaseorder(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->findPurchaseorder: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;outletId\&quot;   - \&quot;supplierId\&quot;   - \&quot;note\&quot;   - \&quot;ingredients\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<PurchaseOrder>**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPurchaseorderByID**
> PurchaseOrder getPurchaseorderByID(authorization, xAPIKey, outletId)

Get Purchaseorder By ID

Get Purchaseorder By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var outletId = outletId_example; // String | 

try { 
    var result = api_instance.getPurchaseorderByID(authorization, xAPIKey, outletId);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->getPurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **outletId** | **String**|  | 

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePurchaseorderByID**
> PurchaseOrder updatePurchaseorderByID(authorization, xAPIKey, outletId, body)

Update Purchaseorder By ID

Update [object Object] By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var outletId = outletId_example; // String | 
var body = new PurchaseOrder(); // PurchaseOrder | 

try { 
    var result = api_instance.updatePurchaseorderByID(authorization, xAPIKey, outletId, body);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->updatePurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **outletId** | **String**|  | 
 **body** | [**PurchaseOrder**](PurchaseOrder.md)|  | 

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.0.2.tar.gz: docs/PurchaseOrderApi.md <==
# swagger.api.PurchaseOrderApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createPurchaseorder**](PurchaseOrderApi.md#createPurchaseorder) | **POST** /purchase-order | Create Purchaseorder
[**deletePurchaseorderByID**](PurchaseOrderApi.md#deletePurchaseorderByID) | **DELETE** /purchase-order/{outletId} | Delete Purchaseorder By ID
[**findPurchaseorder**](PurchaseOrderApi.md#findPurchaseorder) | **GET** /purchase-order | Get Purchaseorder List
[**getPurchaseorderByID**](PurchaseOrderApi.md#getPurchaseorderByID) | **GET** /purchase-order/{outletId} | Get Purchaseorder By ID
[**updatePurchaseorderByID**](PurchaseOrderApi.md#updatePurchaseorderByID) | **PUT** /purchase-order/{outletId} | Update Purchaseorder By ID


# **createPurchaseorder**
> PurchaseOrder createPurchaseorder(authorization, xAPIKey, body)

Create Purchaseorder

Create Purchaseorder

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new PurchaseOrder(); // PurchaseOrder | 

try { 
    var result = api_instance.createPurchaseorder(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->createPurchaseorder: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**PurchaseOrder**](PurchaseOrder.md)|  | 

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deletePurchaseorderByID**
> deletePurchaseorderByID(authorization, xAPIKey, outletId)

Delete Purchaseorder By ID

Delete Purchaseorder By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var outletId = outletId_example; // String | 

try { 
    api_instance.deletePurchaseorderByID(authorization, xAPIKey, outletId);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->deletePurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **outletId** | **String**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findPurchaseorder**
> List<PurchaseOrder> findPurchaseorder(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Purchaseorder List

Get Purchaseorder  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"outletId\"   - \"supplierId\"   - \"note\"   - \"ingredients\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findPurchaseorder(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->findPurchaseorder: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;outletId\&quot;   - \&quot;supplierId\&quot;   - \&quot;note\&quot;   - \&quot;ingredients\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<PurchaseOrder>**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPurchaseorderByID**
> PurchaseOrder getPurchaseorderByID(authorization, xAPIKey, outletId)

Get Purchaseorder By ID

Get Purchaseorder By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var outletId = outletId_example; // String | 

try { 
    var result = api_instance.getPurchaseorderByID(authorization, xAPIKey, outletId);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->getPurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **outletId** | **String**|  | 

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePurchaseorderByID**
> PurchaseOrder updatePurchaseorderByID(authorization, xAPIKey, outletId, body)

Update Purchaseorder By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var outletId = outletId_example; // String | 
var body = new PurchaseOrder(); // PurchaseOrder | 

try { 
    var result = api_instance.updatePurchaseorderByID(authorization, xAPIKey, outletId, body);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->updatePurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **outletId** | **String**|  | 
 **body** | [**PurchaseOrder**](PurchaseOrder.md)|  | 

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
